@@ -1,6 +1,4 @@
 import os
-import psutil
-from hurry.filesize import size
 from pyspark.sql import SparkSession
 import pyspark.sql.functions as F
 
@@ -13,7 +11,8 @@ def getSpark() -> SparkSession:
         .config("spark.driver.maxResultSize", 0)
 
         # Get 80% of free memory (this might be a bad idea)
-        .config("spark.driver.memory", size(psutil.virtual_memory().free * 0.8).lower())
+        .config("spark.driver.memory", "21g")
+        .config("spark.dynamicAllocation.enabled", "true")
 
         # PyArrow for dtypes conversions
         .config("spark.sql.execution.arrow.pyspark.enabled", "true")
